@@ -1,21 +1,11 @@
-/*  $Header$
+/*
+ * Copyright (C) 2009 Rich Burridge
  *
- *  Copyright (c) 2009 Rich Burridge
- *           
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
- *           
- *  This program is distributed in the hope that it will be useful, but 
- *  WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
- *  General Public License for more details.
- *           
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- *  02111-1307, USA.
+ * This program is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 2 of the License, or (at your option) any later
+ * version. See http://www.gnu.org/copyleft/gpl.html the full text of the
+ * license.
  */
 
 #include <stdio.h>
@@ -30,13 +20,15 @@
 
 #define MAXLINE 1024
 
+static MpSerializer *result_serializer;
+
 static void
 solve(const char *equation)
 {
     int ret;
     MPEquationOptions options;
     MPNumber z;
-    char *result_str;
+    gchar *result_str = NULL;
     
     memset(&options, 0, sizeof(options));
     options.base = 10;
@@ -50,7 +42,7 @@ solve(const char *equation)
     else if (ret)        
         fprintf(stderr, "Error %d\n", ret);
     else {
-        mp_serializer_to_specific_string(&z, 10, 9, true, true, &result_str);
+        result_str = mp_serializer_to_string(result_serializer, &z);
         printf("%s\n", result_str);
     }
     g_free(result_str);
@@ -85,6 +77,8 @@ main(int argc, char **argv)
     g_type_init ();
     setlocale(LC_ALL, "");
 
+    result_serializer = mp_serializer_new(MP_DISPLAY_FORMAT_AUTOMATIC, 10, 9);
+
     equation = (char *) malloc(MAXLINE * sizeof(char));
     while (1) {
         printf("> ");
